@@ -13,7 +13,6 @@ BEGIN {
         require HTML::Differences;
         HTML::Differences->import('html_text_diff');
     };
-    eval { require WebService::Validator::HTML::W3C; };
     ## use critic
 }
 
@@ -68,11 +67,10 @@ sub tree_from_handler {
 }
 
 sub html_fragment_ok {
-    my $dialects        = ref $_[0] ? shift : {};
-    my $markdown        = shift;
-    my $expect_html     = shift;
-    my $desc            = shift;
-    my $skip_validation = shift;
+    my $dialects    = ref $_[0] ? shift : {};
+    my $markdown    = shift;
+    my $expect_html = shift;
+    my $desc        = shift;
 
     return unless _can_test_html();
 
@@ -85,9 +83,6 @@ sub html_fragment_ok {
                 $markdown,
             );
 
-            _html_validates_ok( $got_html, 'is fragment' )
-                unless $skip_validation;
-
             s/\n+$/\n/ for $got_html, $expect_html;
 
             my $diff = html_text_diff( $got_html, $expect_html );
@@ -131,8 +126,6 @@ $expect_html
 </html>
 EOF
 
-            _html_validates_ok($got_html);
-
             my $diff = html_text_diff( $got_html, $real_expect_html );
             ok( !$diff, $desc )
                 or diag($diff);
@@ -169,72 +162,6 @@ sub _html_for {
     return $got_html;
 }
 
-sub _html_validates_ok {
-    my $got_html    = shift;
-    my $is_fragment = shift;
-
-SKIP: {
-        skip(
-            'The WebService::Validator::HTML::W3C module is completely broken.'
-                . ' See https://rt.cpan.org/Ticket/Display.html?id=122930 for some details.',
-            1
-        );
-    }
-    return;
-
-    #     unless ( $ENV{RELEASE_TESTING} ) {
-    #     SKIP: {
-    #             skip
-    #                 'HTML validation tests with W3C service are only done for release testing',
-    #                 1;
-    #         }
-    #         return;
-    #     }
-
-    #     unless ( WebService::Validator::HTML::W3C->can('new') ) {
-    #     SKIP: {
-    #             skip
-    #                 'HTML validation tests require WebService::Validator::HTML::W3C',
-    #                 1;
-    #         }
-    #         return;
-    #     }
-
-    #     if ($is_fragment) {
-    #         $got_html = <<"EOF";
-    # <!DOCTYPE html>
-    # <html lang="en">
-    # <head>
-    # <meta charset="UTF-8">
-    # <title>Test</title>
-    # </head>
-    # <body>
-    # $got_html
-    # </body>
-    # </html>
-    # EOF
-    #     }
-
-    #     my $v = WebService::Validator::HTML::W3C->new(
-    #         detailed => 1,
-    #     );
-
-    #     $v->validate_markup($got_html);
-
-    #     is( $v->num_errors(), 0, 'no errors from W3C validator' )
-    #         and return;
-
-    #     diag($got_html);
-    #     diag(
-    #         sprintf(
-    #             "line %s\tcol %s\terror: %s",
-    #             $_->line(), $_->col(), $_->msg()
-    #         )
-    #     ) for @{ $v->errors() || [] };
-
-    #     return;
-}
-
 sub _can_test_html {
     return 1 if HTML::Differences->can('html_text_diff');
 
